==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-runner/lxqt-runner_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>ConfigureDialog</name>
    <message>
        <source>LXQt-runner Settings</source>
        <translation type="vanished">LXQt-çalıştırıcı Ayarları</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Çalıştırıcı Ayarları</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Konumlandırma:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Şunda Göster:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="56"/>
        <source>Shortcut:</source>
        <translation>Kısayol:</translation>
    </message>
    <message>
        <source>Top edge of screen</source>
        <translation type="vanished">Ekranın üst köşesi</translation>
    </message>
    <message>
        <source>Center of screen</source>
        <translation type="vanished">Ekranın merkezi</translation>
    </message>
    <message>
        <source>Monitor where the mouse</source>
        <translation type="vanished">Fare konumunda görüntüle</translation>
    </message>
    <message>
        <source>Always on %1 monitor</source>
        <translation type="vanished">Her zaman %1 ekranında</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="60"/>
        <source>Top edge of the screen</source>
        <translation>Ekranın üst köşesi</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="61"/>
        <source>Center of the screen</source>
        <translation>Ekranın merkezi</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Her zaman %1 ekranında</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Sıfırla</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Uygulama başlatıcı </translation>
    </message>
    <message>
        <source>Configure lxqt-runner</source>
        <translation type="vanished">LXQt-çalıştırıcıyı yapılandır</translation>
    </message>
    <message>
        <source>Clear lxqt-runner History</source>
        <translation type="vanished">LXQt-çalıştırıcı geçmişini temizle</translation>
    </message>
    <message>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation type="vanished">Diyaloğu görmek için &quot;%1&quot; üzerine basın</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="93"/>
        <source>Configure</source>
        <translation>Yapılandır</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="97"/>
        <source>Clear History</source>
        <translation>Geçmişi Temizle</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="349"/>
        <source>Show/hide runner dialog</source>
        <translation>Çalıştırıcı penceresini göster/gizle</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../providers.cpp" line="443"/>
        <source>History</source>
        <translation>Geçmiş</translation>
    </message>
    <message>
        <location filename="../../providers.cpp" line="801"/>
        <source>Mathematics</source>
        <translation>İşlemler</translation>
    </message>
    <message>
        <source>LXQt Power Management</source>
        <translation type="vanished">LXQt Güç Yönetimi</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-runner/lxqt-runner_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>ConfigureDialog</name>
    <message>
        <source>LXQt-runner Settings</source>
        <translation type="vanished">LXQt-çalıştırıcı Ayarları</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Çalıştırıcı Ayarları</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Konumlandırma:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Şunda Göster:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="90"/>
        <source>Shortcut:</source>
        <translation>Kısayol:</translation>
    </message>
    <message>
        <source>Top edge of screen</source>
        <translation type="vanished">Ekranın üst köşesi</translation>
    </message>
    <message>
        <source>Center of screen</source>
        <translation type="vanished">Ekranın merkezi</translation>
    </message>
    <message>
        <source>Monitor where the mouse</source>
        <translation type="vanished">Fare konumunda görüntüle</translation>
    </message>
    <message>
        <source>Always on %1 monitor</source>
        <translation type="vanished">Her zaman %1 ekranında</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="60"/>
        <source>Top edge of the screen</source>
        <translation>Ekranın üst köşesi</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="61"/>
        <source>Center of the screen</source>
        <translation>Ekranın merkezi</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Odaklanmış ekran</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Her zaman %1 ekranında</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Sıfırla</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Uygulama başlatıcı </translation>
    </message>
    <message>
        <source>Configure lxqt-runner</source>
        <translation type="vanished">LXQt-çalıştırıcıyı yapılandır</translation>
    </message>
    <message>
        <source>Clear lxqt-runner History</source>
        <translation type="vanished">LXQt-çalıştırıcı geçmişini temizle</translation>
    </message>
    <message>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation type="vanished">Diyaloğu görmek için &quot;%1&quot; üzerine basın</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="94"/>
        <source>Configure</source>
        <translation>Yapılandır</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="98"/>
        <source>Clear History</source>
        <translation>Geçmişi Temizle</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="351"/>
        <source>Show/hide runner dialog</source>
        <translation>Çalıştırıcı penceresini göster/gizle</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../providers.cpp" line="443"/>
        <source>History</source>
        <translation>Geçmiş</translation>
    </message>
    <message>
        <location filename="../../providers.cpp" line="822"/>
        <source>Mathematics</source>
        <translation>İşlemler</translation>
    </message>
    <message>
        <source>LXQt Power Management</source>
        <translation type="vanished">LXQt Güç Yönetimi</translation>
    </message>
</context>
</TS>
